==> cockpit-podman-24-1-x86_64.pkg.tar.zst: usr/share/cockpit/podman/po.es.js <==
(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "es",
  "x-generator": "Weblate 4.0.3"
 },
 "Add item": [
  null,
  ""
 ],
 "Add on build variable": [
  null,
  "Establecer el contenedor en las variables de construcción"
 ],
 "All": [
  null,
  ""
 ],
 "All registries": [
  null,
  ""
 ],
 "An error occured": [
  null,
  ""
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Iniciar podman en el arranque"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU shares": [
  null,
  "CPU compartida"
 ],
 "Cancel": [
  null,
  "Cancelar"
 ],
 "Checkpoint": [
  null,
  ""
 ],
 "Checkpoint container $0": [
  null,
  "Falló hacer el commit en el contenedor $0"
 ],
 "Command": [
  null,
  "Comando"
 ],
 "Commit": [
  null,
  "Commit"
 ],
 "Commit image": [
  null,
  "Commit una imagen"
 ],
 "Console": [
  null,
  "Consola"
 ],
 "Container": [
  null,
  "Contenedores"
 ],
 "Container failed to be created": [
  null,
  "Falló al crear el contenedor"
 ],
 "Container failed to be started": [
  null,
  "Falló al crear el contenedor"
 ],
 "Container is currently running.": [
  null,
  "El contenedor se está ejecutando."
 ],
 "Container is not running": [
  null,
  "El contenedor no se está ejecutando"
 ],
 "Container name": [
  null,
  "Nombre de contenedor"
 ],
 "Container path": [
  null,
  "Ruta del contenedor"
 ],
 "Container port": [
  null,
  "Puerto del contenedor"
 ],
 "Containers": [
  null,
  "Contenedores"
 ],
 "Created": [
  null,
  "Creado"
 ],
 "Delete": [
  null,
  "Eliminar"
 ],
 "Delete $0": [
  null,
  "Eliminar $0"
 ],
 "Delete image": [
  null,
  "Obtener nueva imagen"
 ],
 "Delete tagged images": [
  null,
  "Obtener nueva imagen"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Eliminando un contenedor se borrará toda la información que hay en él."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  ""
 ],
 "Details": [
  null,
  "Detalles"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  ""
 ],
 "Download": [
  null,
  "Descarga"
 ],
 "Entrypoint": [
  null,
  "Punto de entrada"
 ],
 "Environment": [
  null,
  "Entorno"
 ],
 "Error": [
  null,
  ""
 ],
 "Error message": [
  null,
  "Mensaje de error"
 ],
 "Exited": [
  null,
  "Cerrado"
 ],
 "Failed to checkpoint container $0": [
  null,
  "Falló hacer el commit en el contenedor $0"
 ],
 "Failed to commit container $0": [
  null,
  "Falló hacer el commit en el contenedor $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Falló al descargar la imagen $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Falló al forzar el borrado del contenedor $0"
 ],
 "Failed to force stop pod $0": [
  null,
  "Falló al forzar el borrado del contenedor $0"
 ],
 "Failed to pause pod $0": [
  null,
  "Falló al reiniciar el contenedor $0"
 ],
 "Failed to remove container $0": [
  null,
  "Falló al eliminar el contenedor $0"
 ],
 "Failed to restart container $0": [
  null,
  "Falló al reiniciar el contenedor $0"
 ],
 "Failed to restart pod $0": [
  null,
  "Falló al reiniciar el contenedor $0"
 ],
 "Failed to restore container $0": [
  null,
  "Falló al reiniciar el contenedor $0"
 ],
 "Failed to resume pod $0": [
  null,
  "Falló al eliminar el contenedor $0"
 ],
 "Failed to search for images: $0": [
  null,
  "Falló al buscar nuevas imágenes"
 ],
 "Failed to search for new images": [
  null,
  "Falló al buscar nuevas imágenes"
 ],
 "Failed to start container $0": [
  null,
  "Falló al iniciar el contenedor $0"
 ],
 "Failed to start pod $0": [
  null,
  "Falló al iniciar el contenedor $0"
 ],
 "Failed to stop container $0": [
  null,
  "Falló al parar el contenedor $0"
 ],
 "Failed to stop pod $0": [
  null,
  "Falló al parar el contenedor $0"
 ],
 "Force delete": [
  null,
  "Forzar el borrado"
 ],
 "Force restart": [
  null,
  "Forzar el reinicio"
 ],
 "Force stop": [
  null,
  "Forzar la parada"
 ],
 "Format": [
  null,
  "Formato"
 ],
 "Gateway": [
  null,
  ""
 ],
 "Get new image": [
  null,
  "Obtener nueva imagen"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  ""
 ],
 "Host path": [
  null,
  "Ruta del anfitrión"
 ],
 "Host port": [
  null,
  "Puerto del anfitrión"
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP address": [
  null,
  ""
 ],
 "IP prefix length": [
  null,
  ""
 ],
 "Ignore IP address if set statically": [
  null,
  ""
 ],
 "Ignore MAC address if set statically": [
  null,
  ""
 ],
 "Image": [
  null,
  "Imagen"
 ],
 "Image name": [
  null,
  "Nombre de la imagen"
 ],
 "Images": [
  null,
  "Imágenes"
 ],
 "Keep all temporary checkpoint files": [
  null,
  ""
 ],
 "Key": [
  null,
  "Clave"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  ""
 ],
 "Loading logs...": [
  null,
  "Cargando registros..."
 ],
 "Loading...": [
  null,
  "Cargando..."
 ],
 "Logs": [
  null,
  "Registros"
 ],
 "MAC address": [
  null,
  ""
 ],
 "Memory": [
  null,
  "Memoria"
 ],
 "Memory limit": [
  null,
  "Límite de memoria"
 ],
 "Message": [
  null,
  "Mensaje"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  ""
 ],
 "Name": [
  null,
  "Nombre"
 ],
 "No SELinux label": [
  null,
  ""
 ],
 "No containers": [
  null,
  "No hay contenedores"
 ],
 "No containers are using this image": [
  null,
  "No hay contenedores que utilicen esta imagen"
 ],
 "No containers in this pod": [
  null,
  "No hay contenedores que utilicen esta imagen"
 ],
 "No containers that match the current filter": [
  null,
  "No hay contenedores relacionados con los criterios de búsqueda"
 ],
 "No images": [
  null,
  "No hay imágenes"
 ],
 "No images that match the current filter": [
  null,
  "No hay imágenes relacionadas con el criterio de búsqueda"
 ],
 "No results for $0. Please retry another term.": [
  null,
  "No se han encontrados resultados para $0. Por favor intente con otro término."
 ],
 "No running containers": [
  null,
  "No hay contenedores ejecutándose"
 ],
 "On build": [
  null,
  "En construcción"
 ],
 "Only running": [
  null,
  ""
 ],
 "Owner": [
  null,
  "Propietario"
 ],
 "Pause": [
  null,
  "Pausar"
 ],
 "Pause the container": [
  null,
  "Pausar el contenedor"
 ],
 "Paused": [
  null,
  "Pausar"
 ],
 "Please confirm deletion of $0": [
  null,
  "Por favor confirme el borrado de $0"
 ],
 "Please confirm deletion of pod $0": [
  null,
  "Por favor confirme el borrado de $0"
 ],
 "Please confirm force deletion of pod $0": [
  null,
  "Por favor confirme forzar el borrado de $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Por favor confirme forzar el borrado de $0"
 ],
 "Podman containers": [
  null,
  "Contenedores de Podman"
 ],
 "Podman service is not active": [
  null,
  "El servicio de Podman no está activo"
 ],
 "Ports": [
  null,
  "Puertos"
 ],
 "Private": [
  null,
  ""
 ],
 "Pulling": [
  null,
  "Obteniendo"
 ],
 "ReadOnly": [
  null,
  "SoloLectura"
 ],
 "ReadWrite": [
  null,
  "LecturaEscritura"
 ],
 "Remove item": [
  null,
  ""
 ],
 "Remove on build variable": [
  null,
  "Establecer el contenedor en las variables de construcción"
 ],
 "Restart": [
  null,
  "Reiniciar"
 ],
 "Restore": [
  null,
  "Reiniciar"
 ],
 "Restore container $0": [
  null,
  "Falló al eliminar el contenedor $0"
 ],
 "Restore with established TCP connections": [
  null,
  ""
 ],
 "Resume": [
  null,
  ""
 ],
 "Run": [
  null,
  "Ejecutar"
 ],
 "Run image": [
  null,
  "Ejecutar una imagen"
 ],
 "Running": [
  null,
  ""
 ],
 "Search by name or description": [
  null,
  "Buscar por nombre o descripción"
 ],
 "Search for": [
  null,
  "Buscar una imagen"
 ],
 "Search for an image": [
  null,
  "Buscar una imagen"
 ],
 "Set container on build variables": [
  null,
  "Establecer el contenedor en las variables de construcción"
 ],
 "Shared": [
  null,
  "CPU compartida"
 ],
 "Show": [
  null,
  ""
 ],
 "Show intermediate images": [
  null,
  ""
 ],
 "Size": [
  null,
  "Tamaño"
 ],
 "Start": [
  null,
  "Iniciar"
 ],
 "Start podman": [
  null,
  "Iniciar podman"
 ],
 "State": [
  null,
  "Estado"
 ],
 "Stop": [
  null,
  "Parar"
 ],
 "Stopped": [
  null,
  "Parar"
 ],
 "Support preserving established TCP connections": [
  null,
  ""
 ],
 "System": [
  null,
  "Sistema"
 ],
 "System Podman service is also available": [
  null,
  "El servicio del sistema Podman también está disponible"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Etiqueta"
 ],
 "Tags": [
  null,
  "Etiquetas"
 ],
 "Troubleshoot": [
  null,
  "Solución de errores"
 ],
 "Type to filter…": [
  null,
  "Escriba para establecer un criterio de búsqueda…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Levantado desde $0"
 ],
 "Used by": [
  null,
  "Usado por"
 ],
 "User": [
  null,
  ""
 ],
 "User Podman service is also available": [
  null,
  "El usuario del servicio Podman también está disponible"
 ],
 "Value": [
  null,
  "Valor"
 ],
 "Volumes": [
  null,
  "Volúmenes"
 ],
 "With terminal": [
  null,
  "Con terminal"
 ],
 "configured": [
  null,
  ""
 ],
 "container": [
  null,
  "contenedor"
 ],
 "created": [
  null,
  "Creado"
 ],
 "exited": [
  null,
  "Cerrado"
 ],
 "image": [
  null,
  "imagen"
 ],
 "in": [
  null,
  ""
 ],
 "n/a": [
  null,
  "sin/aplicar"
 ],
 "not available": [
  null,
  "no disponible"
 ],
 "paused": [
  null,
  "Pausar"
 ],
 "pod group": [
  null,
  ""
 ],
 "podman": [
  null,
  "podman"
 ],
 "removing": [
  null,
  ""
 ],
 "running": [
  null,
  ""
 ],
 "select all": [
  null,
  ""
 ],
 "stopped": [
  null,
  ""
 ],
 "system": [
  null,
  "sistema"
 ],
 "user": [
  null,
  "usuario"
 ]
}));

==> cockpit-podman-30-1-x86_64.pkg.tar.zst: usr/share/cockpit/podman/po.es.js <==
cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "es",
  "x-generator": "Weblate 4.0.3"
 },
 "Add item": [
  null,
  ""
 ],
 "All": [
  null,
  ""
 ],
 "All registries": [
  null,
  ""
 ],
 "An error occured": [
  null,
  ""
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Iniciar podman en el arranque"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU shares": [
  null,
  "CPU compartida"
 ],
 "Cancel": [
  null,
  "Cancelar"
 ],
 "Checkpoint": [
  null,
  ""
 ],
 "Command": [
  null,
  "Comando"
 ],
 "Commit": [
  null,
  "Commit"
 ],
 "Commit image": [
  null,
  "Commit una imagen"
 ],
 "Console": [
  null,
  "Consola"
 ],
 "Container failed to be created": [
  null,
  "Falló al crear el contenedor"
 ],
 "Container is currently running.": [
  null,
  "El contenedor se está ejecutando."
 ],
 "Container is not running": [
  null,
  "El contenedor no se está ejecutando"
 ],
 "Container name": [
  null,
  "Nombre de contenedor"
 ],
 "Container path": [
  null,
  "Ruta del contenedor"
 ],
 "Container port": [
  null,
  "Puerto del contenedor"
 ],
 "Containers": [
  null,
  "Contenedores"
 ],
 "Created": [
  null,
  "Creado"
 ],
 "Delete": [
  null,
  "Eliminar"
 ],
 "Delete $0": [
  null,
  "Eliminar $0"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Eliminando un contenedor se borrará toda la información que hay en él."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  ""
 ],
 "Details": [
  null,
  "Detalles"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  ""
 ],
 "Download": [
  null,
  "Descarga"
 ],
 "Entrypoint": [
  null,
  "Punto de entrada"
 ],
 "Environment": [
  null,
  "Entorno"
 ],
 "Error": [
  null,
  ""
 ],
 "Error message": [
  null,
  "Mensaje de error"
 ],
 "Error occured while connecting console": [
  null,
  ""
 ],
 "Exited": [
  null,
  "Cerrado"
 ],
 "Failed to commit container $0": [
  null,
  "Falló hacer el commit en el contenedor $0"
 ],
 "Failed to download image $0:$1": [
  null,
  "Falló al descargar la imagen $0:$1"
 ],
 "Failed to force remove container $0": [
  null,
  "Falló al forzar el borrado del contenedor $0"
 ],
 "Failed to remove container $0": [
  null,
  "Falló al eliminar el contenedor $0"
 ],
 "Failed to restart container $0": [
  null,
  "Falló al reiniciar el contenedor $0"
 ],
 "Failed to search for new images": [
  null,
  "Falló al buscar nuevas imágenes"
 ],
 "Failed to start container $0": [
  null,
  "Falló al iniciar el contenedor $0"
 ],
 "Failed to stop container $0": [
  null,
  "Falló al parar el contenedor $0"
 ],
 "Force delete": [
  null,
  "Forzar el borrado"
 ],
 "Force restart": [
  null,
  "Forzar el reinicio"
 ],
 "Force stop": [
  null,
  "Forzar la parada"
 ],
 "Format": [
  null,
  "Formato"
 ],
 "Gateway": [
  null,
  ""
 ],
 "Get new image": [
  null,
  "Obtener nueva imagen"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  ""
 ],
 "Host path": [
  null,
  "Ruta del anfitrión"
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP (optional)": [
  null,
  ""
 ],
 "IP address": [
  null,
  ""
 ],
 "IP prefix length": [
  null,
  ""
 ],
 "Ignore IP address if set statically": [
  null,
  ""
 ],
 "Ignore MAC address if set statically": [
  null,
  ""
 ],
 "Image": [
  null,
  "Imagen"
 ],
 "Image name": [
  null,
  "Nombre de la imagen"
 ],
 "Images": [
  null,
  "Imágenes"
 ],
 "Keep all temporary checkpoint files": [
  null,
  ""
 ],
 "Key": [
  null,
  "Clave"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  ""
 ],
 "Loading logs...": [
  null,
  "Cargando registros..."
 ],
 "Loading...": [
  null,
  "Cargando..."
 ],
 "Logs": [
  null,
  "Registros"
 ],
 "MAC address": [
  null,
  ""
 ],
 "Memory": [
  null,
  "Memoria"
 ],
 "Memory limit": [
  null,
  "Límite de memoria"
 ],
 "Message": [
  null,
  "Mensaje"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Mode": [
  null,
  ""
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  ""
 ],
 "Name": [
  null,
  "Nombre"
 ],
 "No SELinux label": [
  null,
  ""
 ],
 "No containers": [
  null,
  "No hay contenedores"
 ],
 "No containers are using this image": [
  null,
  "No hay contenedores que utilicen esta imagen"
 ],
 "No containers that match the current filter": [
  null,
  "No hay contenedores relacionados con los criterios de búsqueda"
 ],
 "No images": [
  null,
  "No hay imágenes"
 ],
 "No images that match the current filter": [
  null,
  "No hay imágenes relacionadas con el criterio de búsqueda"
 ],
 "No results for $0": [
  null,
  ""
 ],
 "No running containers": [
  null,
  "No hay contenedores ejecutándose"
 ],
 "Only running": [
  null,
  ""
 ],
 "Owner": [
  null,
  "Propietario"
 ],
 "Pause": [
  null,
  "Pausar"
 ],
 "Pause the container": [
  null,
  "Pausar el contenedor"
 ],
 "Please confirm deletion of $0": [
  null,
  "Por favor confirme el borrado de $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Por favor confirme forzar el borrado de $0"
 ],
 "Please start typing to look for images.": [
  null,
  ""
 ],
 "Podman containers": [
  null,
  "Contenedores de Podman"
 ],
 "Podman service is not active": [
  null,
  "El servicio de Podman no está activo"
 ],
 "Ports": [
  null,
  "Puertos"
 ],
 "Private": [
  null,
  ""
 ],
 "Protocol": [
  null,
  ""
 ],
 "Pulling": [
  null,
  "Obteniendo"
 ],
 "ReadOnly": [
  null,
  "SoloLectura"
 ],
 "ReadWrite": [
  null,
  "LecturaEscritura"
 ],
 "Remove item": [
  null,
  ""
 ],
 "Restart": [
  null,
  "Reiniciar"
 ],
 "Restore with established TCP connections": [
  null,
  ""
 ],
 "Resume": [
  null,
  ""
 ],
 "Run": [
  null,
  "Ejecutar"
 ],
 "Run image": [
  null,
  "Ejecutar una imagen"
 ],
 "Running": [
  null,
  ""
 ],
 "SELinux label": [
  null,
  ""
 ],
 "Search by name or description": [
  null,
  "Buscar por nombre o descripción"
 ],
 "Set container on build variables": [
  null,
  "Establecer el contenedor en las variables de construcción"
 ],
 "Show": [
  null,
  ""
 ],
 "Show intermediate images": [
  null,
  ""
 ],
 "Size": [
  null,
  "Tamaño"
 ],
 "Start": [
  null,
  "Iniciar"
 ],
 "Start podman": [
  null,
  "Iniciar podman"
 ],
 "State": [
  null,
  "Estado"
 ],
 "Stop": [
  null,
  "Parar"
 ],
 "Support preserving established TCP connections": [
  null,
  ""
 ],
 "System": [
  null,
  "Sistema"
 ],
 "System Podman service is also available": [
  null,
  "El servicio del sistema Podman también está disponible"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Etiqueta"
 ],
 "Tags": [
  null,
  "Etiquetas"
 ],
 "Troubleshoot": [
  null,
  "Solución de errores"
 ],
 "Type to filter…": [
  null,
  "Escriba para establecer un criterio de búsqueda…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Levantado desde $0"
 ],
 "Used by": [
  null,
  "Usado por"
 ],
 "User": [
  null,
  ""
 ],
 "User Podman service is also available": [
  null,
  "El usuario del servicio Podman también está disponible"
 ],
 "Value": [
  null,
  "Valor"
 ],
 "Volumes": [
  null,
  "Volúmenes"
 ],
 "With terminal": [
  null,
  "Con terminal"
 ],
 "configured": [
  null,
  ""
 ],
 "container": [
  null,
  "contenedor"
 ],
 "image": [
  null,
  "imagen"
 ],
 "in": [
  null,
  ""
 ],
 "n/a": [
  null,
  "sin/aplicar"
 ],
 "not available": [
  null,
  "no disponible"
 ],
 "pod group": [
  null,
  ""
 ],
 "podman": [
  null,
  "podman"
 ],
 "removing": [
  null,
  ""
 ],
 "running": [
  null,
  ""
 ],
 "select all": [
  null,
  ""
 ],
 "stopped": [
  null,
  ""
 ],
 "system": [
  null,
  "sistema"
 ]
});
